aboutsummaryrefslogtreecommitdiff
path: root/Plugins/SessionCacheServer
diff options
context:
space:
mode:
Diffstat (limited to 'Plugins/SessionCacheServer')
-rw-r--r--Plugins/SessionCacheServer/Endpoints/BrokerHeartBeat.cs22
-rw-r--r--Plugins/SessionCacheServer/Endpoints/ConnectEndpoint.cs22
-rw-r--r--Plugins/SessionCacheServer/ObjectCacheServer.csproj (renamed from Plugins/SessionCacheServer/SessionCacheServer.csproj)2
-rw-r--r--Plugins/SessionCacheServer/ObjectCacheServerEntry.cs (renamed from Plugins/SessionCacheServer/SessionServerEntrypoint.cs)30
4 files changed, 38 insertions, 38 deletions
diff --git a/Plugins/SessionCacheServer/Endpoints/BrokerHeartBeat.cs b/Plugins/SessionCacheServer/Endpoints/BrokerHeartBeat.cs
index dc31575..bad0f7a 100644
--- a/Plugins/SessionCacheServer/Endpoints/BrokerHeartBeat.cs
+++ b/Plugins/SessionCacheServer/Endpoints/BrokerHeartBeat.cs
@@ -2,24 +2,24 @@
* Copyright (c) 2022 Vaughn Nugent
*
* Library: VNLib
-* Package: SessionCacheServer
+* Package: ObjectCacheServer
* File: BrokerHeartBeat.cs
*
-* BrokerHeartBeat.cs is part of SessionCacheServer which is part of the larger
+* BrokerHeartBeat.cs is part of ObjectCacheServer which is part of the larger
* VNLib collection of libraries and utilities.
*
-* SessionCacheServer is free software: you can redistribute it and/or modify
-* it under the terms of the GNU General Public License as published
-* by the Free Software Foundation, either version 2 of the License,
-* or (at your option) any later version.
+* ObjectCacheServer is free software: you can redistribute it and/or modify
+* it under the terms of the GNU Affero General Public License as
+* published by the Free Software Foundation, either version 3 of the
+* License, or (at your option) any later version.
*
-* SessionCacheServer is distributed in the hope that it will be useful,
+* ObjectCacheServer is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-* General Public License for more details.
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+* GNU Affero General Public License for more details.
*
-* You should have received a copy of the GNU General Public License
-* along with SessionCacheServer. If not, see http://www.gnu.org/licenses/.
+* You should have received a copy of the GNU Affero General Public License
+* along with this program. If not, see https://www.gnu.org/licenses/.
*/
using System;
diff --git a/Plugins/SessionCacheServer/Endpoints/ConnectEndpoint.cs b/Plugins/SessionCacheServer/Endpoints/ConnectEndpoint.cs
index 56c7036..dc94825 100644
--- a/Plugins/SessionCacheServer/Endpoints/ConnectEndpoint.cs
+++ b/Plugins/SessionCacheServer/Endpoints/ConnectEndpoint.cs
@@ -2,24 +2,24 @@
* Copyright (c) 2022 Vaughn Nugent
*
* Library: VNLib
-* Package: SessionCacheServer
+* Package: ObjectCacheServer
* File: ConnectEndpoint.cs
*
-* ConnectEndpoint.cs is part of SessionCacheServer which is part of the larger
+* ConnectEndpoint.cs is part of ObjectCacheServer which is part of the larger
* VNLib collection of libraries and utilities.
*
-* SessionCacheServer is free software: you can redistribute it and/or modify
-* it under the terms of the GNU General Public License as published
-* by the Free Software Foundation, either version 2 of the License,
-* or (at your option) any later version.
+* ObjectCacheServer is free software: you can redistribute it and/or modify
+* it under the terms of the GNU Affero General Public License as
+* published by the Free Software Foundation, either version 3 of the
+* License, or (at your option) any later version.
*
-* SessionCacheServer is distributed in the hope that it will be useful,
+* ObjectCacheServer is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-* General Public License for more details.
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+* GNU Affero General Public License for more details.
*
-* You should have received a copy of the GNU General Public License
-* along with SessionCacheServer. If not, see http://www.gnu.org/licenses/.
+* You should have received a copy of the GNU Affero General Public License
+* along with this program. If not, see https://www.gnu.org/licenses/.
*/
using System;
diff --git a/Plugins/SessionCacheServer/SessionCacheServer.csproj b/Plugins/SessionCacheServer/ObjectCacheServer.csproj
index 580bac3..5598acc 100644
--- a/Plugins/SessionCacheServer/SessionCacheServer.csproj
+++ b/Plugins/SessionCacheServer/ObjectCacheServer.csproj
@@ -42,7 +42,7 @@
<ItemGroup>
- <None Update="SessionCacheServer.json">
+ <None Update="ObjectCacheServer.json">
<CopyToOutputDirectory>Always</CopyToOutputDirectory>
</None>
</ItemGroup>
diff --git a/Plugins/SessionCacheServer/SessionServerEntrypoint.cs b/Plugins/SessionCacheServer/ObjectCacheServerEntry.cs
index c7b0914..6c969ba 100644
--- a/Plugins/SessionCacheServer/SessionServerEntrypoint.cs
+++ b/Plugins/SessionCacheServer/ObjectCacheServerEntry.cs
@@ -2,24 +2,24 @@
* Copyright (c) 2022 Vaughn Nugent
*
* Library: VNLib
* Package: SessionCacheServer
* File: SessionServerEntrypoint.cs
*
* SessionServerEntrypoint.cs is part of SessionCacheServer which is part of the larger
* VNLib collection of libraries and utilities.
*
* SessionCacheServer is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published
* by the Free Software Foundation, either version 2 of the License,
* or (at your option) any later version.
*
* SessionCacheServer is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-* General Public License for more details.
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+* GNU Affero General Public License for more details.
*
-* You should have received a copy of the GNU General Public License
-* along with SessionCacheServer. If not, see http://www.gnu.org/licenses/.
+* You should have received a copy of the GNU Affero General Public License
+* along with this program. If not, see https://www.gnu.org/licenses/.
*/
using System;
@@ -53,9 +53,9 @@ using VNLib.Plugins.Essentials.Sessions.Server.Endpoints;
namespace VNLib.Plugins.Essentials.Sessions.Server
{
- public sealed class SessionServerEntrypoint : PluginBase
+ public sealed class ObjectCacheServerEntry : PluginBase
{
- public override string PluginName => "Session.Cache.Service";
+ public override string PluginName => "ObjectCache.Service";
private string? BrokerHeartBeatToken;
@@ -69,7 +69,7 @@ namespace VNLib.Plugins.Essentials.Sessions.Server
string brokerAddress = clusterConf["broker_address"].GetString() ?? throw new KeyNotFoundException("Missing required key 'broker_address' for config 'cluster'");
- string swapDir = PluginConfig.GetProperty("swap_dir").GetString();
+ string swapDir = PluginConfig.GetProperty("swap_dir").GetString() ?? throw new KeyNotFoundException("Missing required key 'swap_dir' for config");
int cacheSize = PluginConfig.GetProperty("max_cache").GetInt32();
string connectPath = PluginConfig.GetProperty("connect_path").GetString() ?? throw new KeyNotFoundException("Missing required element 'connect_path' for config 'cluster'");
TimeSpan cleanupInterval = PluginConfig.GetProperty("cleanup_interval_sec").GetTimeSpan(TimeParseType.Seconds);
@@ -2,24 +2,24 @@
*
* Library: VNLib
-* Package: SessionCacheServer
-* File: SessionServerEntrypoint.cs
+* Package: ObjectCacheServer
+* File: ObjectCacheServerEntry.cs
*
@@ -2,24 +2,24 @@
*
-* SessionServerEntrypoint.cs is part of SessionCacheServer which is part of the larger
+* ObjectCacheServerEntry.cs is part of ObjectCacheServer which is part of the larger
* VNLib collection of libraries and utilities.
*
@@ -2,24 +2,24 @@
* VNLib collection of libraries and utilities.
*
-* SessionCacheServer is free software: you can redistribute it and/or modify
-* it under the terms of the GNU General Public License as published
-* by the Free Software Foundation, either version 2 of the License,
-* or (at your option) any later version.
+* ObjectCacheServer is free software: you can redistribute it and/or modify
+* it under the terms of the GNU Affero General Public License as
+* published by the Free Software Foundation, either version 3 of the
+* License, or (at your option) any later version.
*
@@ -2,24 +2,24 @@
*
-* SessionCacheServer is distributed in the hope that it will be useful,
+* ObjectCacheServer is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of